Macros
- dependencies
- The
dependencies!macro allows users to specify all task dependencies in an easy-to-understand way. It will return the generated graph structure based on a set of defined dependencies
Attribute Macros
- auto_
node - [
auto_node] is a macro that may be used when customizing nodes. It can only be marked on named struct or unit struct.